import datetime
import java
import java.io
import java.lang
import java.time
import java.time.format
import java.time.temporal
import java.util
import typing



class ChronoLocalDate(java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster, java.lang.Comparable['ChronoLocalDate']):
    def adjustInto(self, temporal: java.time.temporal.Temporal) -> java.time.temporal.Temporal: ...
    def atTime(self, localTime: java.time.LocalTime) -> 'ChronoLocalDateTime'[typing.Any]: ...
    def compareTo(self, chronoLocalDate: 'ChronoLocalDate') -> int: ...
    def equals(self, object: typing.Any) -> bool: ...
    def format(self, dateTimeFormatter: java.time.format.DateTimeFormatter) -> str: ...
    def getChronology(self) -> 'Chronology': ...
    def getEra(self) -> 'Era': ...
    def hashCode(self) -> int: ...
    def isAfter(self, chronoLocalDate: 'ChronoLocalDate') -> bool: ...
    def isBefore(self, chronoLocalDate: 'ChronoLocalDate') -> bool: ...
    def isEqual(self, chronoLocalDate: 'ChronoLocalDate') -> bool: ...
    def isLeapYear(self) -> bool: ...
    @typing.overload
    def isSupported(self, temporalField: java.time.temporal.TemporalField) -> bool: ...
    @typing.overload
    def isSupported(self, temporalUnit: java.time.temporal.TemporalUnit) -> bool: ...
    def lengthOfMonth(self) -> int: ...
    def lengthOfYear(self) -> int: ...
    @typing.overload
    def minus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'ChronoLocalDate': ...
    @typing.overload
    def minus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'ChronoLocalDate': ...
    @typing.overload
    def plus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'ChronoLocalDate': ...
    @typing.overload
    def plus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'ChronoLocalDate': ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, temporalQuery: typing.Union[java.time.temporal.TemporalQuery[_query__R], typing.Callable[[java.time.temporal.TemporalAccessor], _query__R]]) -> _query__R: ...
    @staticmethod
    def timeLineOrder() -> java.util.Comparator['ChronoLocalDate']: ...
    def toEpochDay(self) -> int: ...
    def toString(self) -> str: ...
    @typing.overload
    def until(self, chronoLocalDate: 'ChronoLocalDate') -> 'ChronoPeriod': ...
    @typing.overload
    def until(self, temporal: java.time.temporal.Temporal, temporalUnit: java.time.temporal.TemporalUnit) -> int: ...

_ChronoLocalDateTime__D = typing.TypeVar('_ChronoLocalDateTime__D', bound=ChronoLocalDate)  # <D>
class ChronoLocalDateTime(java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster, java.lang.Comparable['ChronoLocalDateTime'[typing.Any]], typing.Generic[_ChronoLocalDateTime__D]):
    def adjustInto(self, temporal: java.time.temporal.Temporal) -> java.time.temporal.Temporal: ...
    def atZone(self, zoneId: java.time.ZoneId) -> 'ChronoZonedDateTime'[_ChronoLocalDateTime__D]: ...
    def compareTo(self, chronoLocalDateTime: 'ChronoLocalDateTime'[typing.Any]) -> int: ...
    def equals(self, object: typing.Any) -> bool: ...
    def format(self, dateTimeFormatter: java.time.format.DateTimeFormatter) -> str: ...
    def getChronology(self) -> 'Chronology': ...
    def hashCode(self) -> int: ...
    def isAfter(self, chronoLocalDateTime: 'ChronoLocalDateTime'[typing.Any]) -> bool: ...
    def isBefore(self, chronoLocalDateTime: 'ChronoLocalDateTime'[typing.Any]) -> bool: ...
    def isEqual(self, chronoLocalDateTime: 'ChronoLocalDateTime'[typing.Any]) -> bool: ...
    @typing.overload
    def isSupported(self, temporalField: java.time.temporal.TemporalField) -> bool: ...
    @typing.overload
    def isSupported(self, temporalUnit: java.time.temporal.TemporalUnit) -> bool: ...
    @typing.overload
    def minus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'ChronoLocalDateTime'[_ChronoLocalDateTime__D]: ...
    @typing.overload
    def minus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'ChronoLocalDateTime'[_ChronoLocalDateTime__D]: ...
    @typing.overload
    def plus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'ChronoLocalDateTime'[_ChronoLocalDateTime__D]: ...
    @typing.overload
    def plus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'ChronoLocalDateTime'[_ChronoLocalDateTime__D]: ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, temporalQuery: typing.Union[java.time.temporal.TemporalQuery[_query__R], typing.Callable[[java.time.temporal.TemporalAccessor], _query__R]]) -> _query__R: ...
    @staticmethod
    def timeLineOrder() -> java.util.Comparator['ChronoLocalDateTime'[typing.Any]]: ...
    def toEpochSecond(self, zoneOffset: java.time.ZoneOffset) -> int: ...
    def toInstant(self, zoneOffset: java.time.ZoneOffset) -> java.time.Instant: ...
    def toLocalDate(self) -> _ChronoLocalDateTime__D: ...
    def toLocalTime(self) -> java.time.LocalTime: ...
    def toString(self) -> str: ...

class ChronoPeriod(java.time.temporal.TemporalAmount):
    def addTo(self, temporal: java.time.temporal.Temporal) -> java.time.temporal.Temporal: ...
    @staticmethod
    def between(chronoLocalDate: ChronoLocalDate, chronoLocalDate2: ChronoLocalDate) -> 'ChronoPeriod': ...
    def equals(self, object: typing.Any) -> bool: ...
    def get(self, temporalUnit: java.time.temporal.TemporalUnit) -> int: ...
    def getChronology(self) -> 'Chronology': ...
    def getUnits(self) -> java.util.List[java.time.temporal.TemporalUnit]: ...
    def hashCode(self) -> int: ...
    def isNegative(self) -> bool: ...
    def isZero(self) -> bool: ...
    def minus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'ChronoPeriod': ...
    def multipliedBy(self, int: int) -> 'ChronoPeriod': ...
    def negated(self) -> 'ChronoPeriod': ...
    def normalized(self) -> 'ChronoPeriod': ...
    def plus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'ChronoPeriod': ...
    def subtractFrom(self, temporal: java.time.temporal.Temporal) -> java.time.temporal.Temporal: ...
    def toString(self) -> str: ...

_ChronoZonedDateTime__D = typing.TypeVar('_ChronoZonedDateTime__D', bound=ChronoLocalDate)  # <D>
class ChronoZonedDateTime(java.time.temporal.Temporal, java.lang.Comparable['ChronoZonedDateTime'[typing.Any]], typing.Generic[_ChronoZonedDateTime__D]):
    def compareTo(self, chronoZonedDateTime: 'ChronoZonedDateTime'[typing.Any]) -> int: ...
    def equals(self, object: typing.Any) -> bool: ...
    def format(self, dateTimeFormatter: java.time.format.DateTimeFormatter) -> str: ...
    def get(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getChronology(self) -> 'Chronology': ...
    def getLong(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getOffset(self) -> java.time.ZoneOffset: ...
    def getZone(self) -> java.time.ZoneId: ...
    def hashCode(self) -> int: ...
    def isAfter(self, chronoZonedDateTime: 'ChronoZonedDateTime'[typing.Any]) -> bool: ...
    def isBefore(self, chronoZonedDateTime: 'ChronoZonedDateTime'[typing.Any]) -> bool: ...
    def isEqual(self, chronoZonedDateTime: 'ChronoZonedDateTime'[typing.Any]) -> bool: ...
    @typing.overload
    def isSupported(self, temporalField: java.time.temporal.TemporalField) -> bool: ...
    @typing.overload
    def isSupported(self, temporalUnit: java.time.temporal.TemporalUnit) -> bool: ...
    @typing.overload
    def minus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'ChronoZonedDateTime'[_ChronoZonedDateTime__D]: ...
    @typing.overload
    def minus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'ChronoZonedDateTime'[_ChronoZonedDateTime__D]: ...
    @typing.overload
    def plus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'ChronoZonedDateTime'[_ChronoZonedDateTime__D]: ...
    @typing.overload
    def plus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'ChronoZonedDateTime'[_ChronoZonedDateTime__D]: ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, temporalQuery: typing.Union[java.time.temporal.TemporalQuery[_query__R], typing.Callable[[java.time.temporal.TemporalAccessor], _query__R]]) -> _query__R: ...
    def range(self, temporalField: java.time.temporal.TemporalField) -> java.time.temporal.ValueRange: ...
    @staticmethod
    def timeLineOrder() -> java.util.Comparator['ChronoZonedDateTime'[typing.Any]]: ...
    def toEpochSecond(self) -> int: ...
    def toInstant(self) -> java.time.Instant: ...
    def toLocalDate(self) -> _ChronoZonedDateTime__D: ...
    def toLocalDateTime(self) -> ChronoLocalDateTime[_ChronoZonedDateTime__D]: ...
    def toLocalTime(self) -> java.time.LocalTime: ...
    def toString(self) -> str: ...
    def withEarlierOffsetAtOverlap(self) -> 'ChronoZonedDateTime'[_ChronoZonedDateTime__D]: ...
    def withLaterOffsetAtOverlap(self) -> 'ChronoZonedDateTime'[_ChronoZonedDateTime__D]: ...
    def withZoneSameInstant(self, zoneId: java.time.ZoneId) -> 'ChronoZonedDateTime'[_ChronoZonedDateTime__D]: ...
    def withZoneSameLocal(self, zoneId: java.time.ZoneId) -> 'ChronoZonedDateTime'[_ChronoZonedDateTime__D]: ...

class Chronology(java.lang.Comparable['Chronology']):
    def compareTo(self, chronology: 'Chronology') -> int: ...
    @typing.overload
    def date(self, int: int, int2: int, int3: int) -> ChronoLocalDate: ...
    @typing.overload
    def date(self, temporalAccessor: java.time.temporal.TemporalAccessor) -> ChronoLocalDate: ...
    @typing.overload
    def date(self, era: 'Era', int: int, int2: int, int3: int) -> ChronoLocalDate: ...
    def dateEpochDay(self, long: int) -> ChronoLocalDate: ...
    @typing.overload
    def dateNow(self) -> ChronoLocalDate: ...
    @typing.overload
    def dateNow(self, clock: java.time.Clock) -> ChronoLocalDate: ...
    @typing.overload
    def dateNow(self, zoneId: java.time.ZoneId) -> ChronoLocalDate: ...
    @typing.overload
    def dateYearDay(self, int: int, int2: int) -> ChronoLocalDate: ...
    @typing.overload
    def dateYearDay(self, era: 'Era', int: int, int2: int) -> ChronoLocalDate: ...
    @typing.overload
    def epochSecond(self, int: int, int2: int, int3: int, int4: int, int5: int, int6: int, zoneOffset: java.time.ZoneOffset) -> int: ...
    @typing.overload
    def epochSecond(self, era: 'Era', int: int, int2: int, int3: int, int4: int, int5: int, int6: int, zoneOffset: java.time.ZoneOffset) -> int: ...
    def equals(self, object: typing.Any) -> bool: ...
    def eraOf(self, int: int) -> 'Era': ...
    def eras(self) -> java.util.List['Era']: ...
    @staticmethod
    def getAvailableChronologies() -> java.util.Set['Chronology']: ...
    def getCalendarType(self) -> str: ...
    def getDisplayName(self, textStyle: java.time.format.TextStyle, locale: java.util.Locale) -> str: ...
    def getId(self) -> str: ...
    def hashCode(self) -> int: ...
    def isLeapYear(self, long: int) -> bool: ...
    def localDateTime(self, temporalAccessor: java.time.temporal.TemporalAccessor) -> ChronoLocalDateTime[ChronoLocalDate]: ...
    @staticmethod
    def of(string: str) -> 'Chronology': ...
    @staticmethod
    def ofLocale(locale: java.util.Locale) -> 'Chronology': ...
    def period(self, int: int, int2: int, int3: int) -> ChronoPeriod: ...
    def prolepticYear(self, era: 'Era', int: int) -> int: ...
    def range(self, chronoField: java.time.temporal.ChronoField) -> java.time.temporal.ValueRange: ...
    def resolveDate(self, map: typing.Union[java.util.Map[java.time.temporal.TemporalField, int], typing.Mapping[java.time.temporal.TemporalField, int]], resolverStyle: java.time.format.ResolverStyle) -> ChronoLocalDate: ...
    def toString(self) -> str: ...
    @typing.overload
    def zonedDateTime(self, instant: typing.Union[java.time.Instant, datetime.datetime], zoneId: java.time.ZoneId) -> ChronoZonedDateTime[ChronoLocalDate]: ...
    @typing.overload
    def zonedDateTime(self, temporalAccessor: java.time.temporal.TemporalAccessor) -> ChronoZonedDateTime[ChronoLocalDate]: ...

class Era(java.time.temporal.TemporalAccessor, java.time.temporal.TemporalAdjuster):
    def adjustInto(self, temporal: java.time.temporal.Temporal) -> java.time.temporal.Temporal: ...
    def get(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getDisplayName(self, textStyle: java.time.format.TextStyle, locale: java.util.Locale) -> str: ...
    def getLong(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getValue(self) -> int: ...
    def isSupported(self, temporalField: java.time.temporal.TemporalField) -> bool: ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, temporalQuery: typing.Union[java.time.temporal.TemporalQuery[_query__R], typing.Callable[[java.time.temporal.TemporalAccessor], _query__R]]) -> _query__R: ...
    def range(self, temporalField: java.time.temporal.TemporalField) -> java.time.temporal.ValueRange: ...

class AbstractChronology(Chronology):
    def compareTo(self, chronology: Chronology) -> int: ...
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def resolveDate(self, map: typing.Union[java.util.Map[java.time.temporal.TemporalField, int], typing.Mapping[java.time.temporal.TemporalField, int]], resolverStyle: java.time.format.ResolverStyle) -> ChronoLocalDate: ...
    def toString(self) -> str: ...

class HijrahEra(java.lang.Enum['HijrahEra'], Era):
    AH: typing.ClassVar['HijrahEra'] = ...
    def getDisplayName(self, textStyle: java.time.format.TextStyle, locale: java.util.Locale) -> str: ...
    def getValue(self) -> int: ...
    @staticmethod
    def of(int: int) -> 'HijrahEra': ...
    def range(self, temporalField: java.time.temporal.TemporalField) -> java.time.temporal.ValueRange: ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'HijrahEra': ...
    @staticmethod
    def values() -> typing.List['HijrahEra']: ...

class IsoEra(java.lang.Enum['IsoEra'], Era):
    BCE: typing.ClassVar['IsoEra'] = ...
    CE: typing.ClassVar['IsoEra'] = ...
    def getValue(self) -> int: ...
    @staticmethod
    def of(int: int) -> 'IsoEra': ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'IsoEra': ...
    @staticmethod
    def values() -> typing.List['IsoEra']: ...

class JapaneseEra(Era, java.io.Serializable):
    MEIJI: typing.ClassVar['JapaneseEra'] = ...
    TAISHO: typing.ClassVar['JapaneseEra'] = ...
    SHOWA: typing.ClassVar['JapaneseEra'] = ...
    HEISEI: typing.ClassVar['JapaneseEra'] = ...
    def getDisplayName(self, textStyle: java.time.format.TextStyle, locale: java.util.Locale) -> str: ...
    def getValue(self) -> int: ...
    @staticmethod
    def of(int: int) -> 'JapaneseEra': ...
    def range(self, temporalField: java.time.temporal.TemporalField) -> java.time.temporal.ValueRange: ...
    def toString(self) -> str: ...
    @staticmethod
    def valueOf(string: str) -> 'JapaneseEra': ...
    @staticmethod
    def values() -> typing.List['JapaneseEra']: ...

class MinguoEra(java.lang.Enum['MinguoEra'], Era):
    BEFORE_ROC: typing.ClassVar['MinguoEra'] = ...
    ROC: typing.ClassVar['MinguoEra'] = ...
    def getDisplayName(self, textStyle: java.time.format.TextStyle, locale: java.util.Locale) -> str: ...
    def getValue(self) -> int: ...
    @staticmethod
    def of(int: int) -> 'MinguoEra': ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'MinguoEra': ...
    @staticmethod
    def values() -> typing.List['MinguoEra']: ...

class ThaiBuddhistEra(java.lang.Enum['ThaiBuddhistEra'], Era):
    BEFORE_BE: typing.ClassVar['ThaiBuddhistEra'] = ...
    BE: typing.ClassVar['ThaiBuddhistEra'] = ...
    def getDisplayName(self, textStyle: java.time.format.TextStyle, locale: java.util.Locale) -> str: ...
    def getValue(self) -> int: ...
    @staticmethod
    def of(int: int) -> 'ThaiBuddhistEra': ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'ThaiBuddhistEra': ...
    @staticmethod
    def values() -> typing.List['ThaiBuddhistEra']: ...

class HijrahChronology(AbstractChronology, java.io.Serializable):
    INSTANCE: typing.ClassVar['HijrahChronology'] = ...
    @typing.overload
    def date(self, int: int, int2: int, int3: int) -> 'HijrahDate': ...
    @typing.overload
    def date(self, era: Era, int: int, int2: int, int3: int) -> 'HijrahDate': ...
    @typing.overload
    def date(self, temporalAccessor: java.time.temporal.TemporalAccessor) -> 'HijrahDate': ...
    def dateEpochDay(self, long: int) -> 'HijrahDate': ...
    @typing.overload
    def dateNow(self) -> 'HijrahDate': ...
    @typing.overload
    def dateNow(self, clock: java.time.Clock) -> 'HijrahDate': ...
    @typing.overload
    def dateNow(self, zoneId: java.time.ZoneId) -> 'HijrahDate': ...
    @typing.overload
    def dateYearDay(self, int: int, int2: int) -> 'HijrahDate': ...
    @typing.overload
    def dateYearDay(self, era: Era, int: int, int2: int) -> 'HijrahDate': ...
    def eraOf(self, int: int) -> HijrahEra: ...
    def eras(self) -> java.util.List[Era]: ...
    def getCalendarType(self) -> str: ...
    def getId(self) -> str: ...
    def isLeapYear(self, long: int) -> bool: ...
    def localDateTime(self, temporalAccessor: java.time.temporal.TemporalAccessor) -> ChronoLocalDateTime['HijrahDate']: ...
    def prolepticYear(self, era: Era, int: int) -> int: ...
    def range(self, chronoField: java.time.temporal.ChronoField) -> java.time.temporal.ValueRange: ...
    def resolveDate(self, map: typing.Union[java.util.Map[java.time.temporal.TemporalField, int], typing.Mapping[java.time.temporal.TemporalField, int]], resolverStyle: java.time.format.ResolverStyle) -> 'HijrahDate': ...
    @typing.overload
    def zonedDateTime(self, instant: typing.Union[java.time.Instant, datetime.datetime], zoneId: java.time.ZoneId) -> ChronoZonedDateTime['HijrahDate']: ...
    @typing.overload
    def zonedDateTime(self, temporalAccessor: java.time.temporal.TemporalAccessor) -> ChronoZonedDateTime['HijrahDate']: ...

class IsoChronology(AbstractChronology, java.io.Serializable):
    INSTANCE: typing.ClassVar['IsoChronology'] = ...
    @typing.overload
    def date(self, int: int, int2: int, int3: int) -> java.time.LocalDate: ...
    @typing.overload
    def date(self, era: Era, int: int, int2: int, int3: int) -> java.time.LocalDate: ...
    @typing.overload
    def date(self, temporalAccessor: java.time.temporal.TemporalAccessor) -> java.time.LocalDate: ...
    def dateEpochDay(self, long: int) -> java.time.LocalDate: ...
    @typing.overload
    def dateNow(self) -> java.time.LocalDate: ...
    @typing.overload
    def dateNow(self, clock: java.time.Clock) -> java.time.LocalDate: ...
    @typing.overload
    def dateNow(self, zoneId: java.time.ZoneId) -> java.time.LocalDate: ...
    @typing.overload
    def dateYearDay(self, int: int, int2: int) -> java.time.LocalDate: ...
    @typing.overload
    def dateYearDay(self, era: Era, int: int, int2: int) -> java.time.LocalDate: ...
    @typing.overload
    def epochSecond(self, era: Era, int: int, int2: int, int3: int, int4: int, int5: int, int6: int, zoneOffset: java.time.ZoneOffset) -> int: ...
    @typing.overload
    def epochSecond(self, int: int, int2: int, int3: int, int4: int, int5: int, int6: int, zoneOffset: java.time.ZoneOffset) -> int: ...
    def eraOf(self, int: int) -> IsoEra: ...
    def eras(self) -> java.util.List[Era]: ...
    def getCalendarType(self) -> str: ...
    def getId(self) -> str: ...
    def isLeapYear(self, long: int) -> bool: ...
    def localDateTime(self, temporalAccessor: java.time.temporal.TemporalAccessor) -> java.time.LocalDateTime: ...
    def period(self, int: int, int2: int, int3: int) -> java.time.Period: ...
    def prolepticYear(self, era: Era, int: int) -> int: ...
    def range(self, chronoField: java.time.temporal.ChronoField) -> java.time.temporal.ValueRange: ...
    def resolveDate(self, map: typing.Union[java.util.Map[java.time.temporal.TemporalField, int], typing.Mapping[java.time.temporal.TemporalField, int]], resolverStyle: java.time.format.ResolverStyle) -> java.time.LocalDate: ...
    @typing.overload
    def zonedDateTime(self, instant: typing.Union[java.time.Instant, datetime.datetime], zoneId: java.time.ZoneId) -> java.time.ZonedDateTime: ...
    @typing.overload
    def zonedDateTime(self, temporalAccessor: java.time.temporal.TemporalAccessor) -> java.time.ZonedDateTime: ...

class JapaneseChronology(AbstractChronology, java.io.Serializable):
    INSTANCE: typing.ClassVar['JapaneseChronology'] = ...
    @typing.overload
    def date(self, int: int, int2: int, int3: int) -> 'JapaneseDate': ...
    @typing.overload
    def date(self, era: Era, int: int, int2: int, int3: int) -> 'JapaneseDate': ...
    @typing.overload
    def date(self, temporalAccessor: java.time.temporal.TemporalAccessor) -> 'JapaneseDate': ...
    def dateEpochDay(self, long: int) -> 'JapaneseDate': ...
    @typing.overload
    def dateNow(self) -> 'JapaneseDate': ...
    @typing.overload
    def dateNow(self, clock: java.time.Clock) -> 'JapaneseDate': ...
    @typing.overload
    def dateNow(self, zoneId: java.time.ZoneId) -> 'JapaneseDate': ...
    @typing.overload
    def dateYearDay(self, int: int, int2: int) -> 'JapaneseDate': ...
    @typing.overload
    def dateYearDay(self, era: Era, int: int, int2: int) -> 'JapaneseDate': ...
    def eraOf(self, int: int) -> JapaneseEra: ...
    def eras(self) -> java.util.List[Era]: ...
    def getCalendarType(self) -> str: ...
    def getId(self) -> str: ...
    def isLeapYear(self, long: int) -> bool: ...
    def localDateTime(self, temporalAccessor: java.time.temporal.TemporalAccessor) -> ChronoLocalDateTime['JapaneseDate']: ...
    def prolepticYear(self, era: Era, int: int) -> int: ...
    def range(self, chronoField: java.time.temporal.ChronoField) -> java.time.temporal.ValueRange: ...
    def resolveDate(self, map: typing.Union[java.util.Map[java.time.temporal.TemporalField, int], typing.Mapping[java.time.temporal.TemporalField, int]], resolverStyle: java.time.format.ResolverStyle) -> 'JapaneseDate': ...
    @typing.overload
    def zonedDateTime(self, instant: typing.Union[java.time.Instant, datetime.datetime], zoneId: java.time.ZoneId) -> ChronoZonedDateTime['JapaneseDate']: ...
    @typing.overload
    def zonedDateTime(self, temporalAccessor: java.time.temporal.TemporalAccessor) -> ChronoZonedDateTime['JapaneseDate']: ...

class MinguoChronology(AbstractChronology, java.io.Serializable):
    INSTANCE: typing.ClassVar['MinguoChronology'] = ...
    @typing.overload
    def date(self, int: int, int2: int, int3: int) -> 'MinguoDate': ...
    @typing.overload
    def date(self, era: Era, int: int, int2: int, int3: int) -> 'MinguoDate': ...
    @typing.overload
    def date(self, temporalAccessor: java.time.temporal.TemporalAccessor) -> 'MinguoDate': ...
    def dateEpochDay(self, long: int) -> 'MinguoDate': ...
    @typing.overload
    def dateNow(self) -> 'MinguoDate': ...
    @typing.overload
    def dateNow(self, clock: java.time.Clock) -> 'MinguoDate': ...
    @typing.overload
    def dateNow(self, zoneId: java.time.ZoneId) -> 'MinguoDate': ...
    @typing.overload
    def dateYearDay(self, int: int, int2: int) -> 'MinguoDate': ...
    @typing.overload
    def dateYearDay(self, era: Era, int: int, int2: int) -> 'MinguoDate': ...
    def eraOf(self, int: int) -> MinguoEra: ...
    def eras(self) -> java.util.List[Era]: ...
    def getCalendarType(self) -> str: ...
    def getId(self) -> str: ...
    def isLeapYear(self, long: int) -> bool: ...
    def localDateTime(self, temporalAccessor: java.time.temporal.TemporalAccessor) -> ChronoLocalDateTime['MinguoDate']: ...
    def prolepticYear(self, era: Era, int: int) -> int: ...
    def range(self, chronoField: java.time.temporal.ChronoField) -> java.time.temporal.ValueRange: ...
    def resolveDate(self, map: typing.Union[java.util.Map[java.time.temporal.TemporalField, int], typing.Mapping[java.time.temporal.TemporalField, int]], resolverStyle: java.time.format.ResolverStyle) -> 'MinguoDate': ...
    @typing.overload
    def zonedDateTime(self, instant: typing.Union[java.time.Instant, datetime.datetime], zoneId: java.time.ZoneId) -> ChronoZonedDateTime['MinguoDate']: ...
    @typing.overload
    def zonedDateTime(self, temporalAccessor: java.time.temporal.TemporalAccessor) -> ChronoZonedDateTime['MinguoDate']: ...

class ThaiBuddhistChronology(AbstractChronology, java.io.Serializable):
    INSTANCE: typing.ClassVar['ThaiBuddhistChronology'] = ...
    @typing.overload
    def date(self, int: int, int2: int, int3: int) -> 'ThaiBuddhistDate': ...
    @typing.overload
    def date(self, era: Era, int: int, int2: int, int3: int) -> 'ThaiBuddhistDate': ...
    @typing.overload
    def date(self, temporalAccessor: java.time.temporal.TemporalAccessor) -> 'ThaiBuddhistDate': ...
    def dateEpochDay(self, long: int) -> 'ThaiBuddhistDate': ...
    @typing.overload
    def dateNow(self) -> 'ThaiBuddhistDate': ...
    @typing.overload
    def dateNow(self, clock: java.time.Clock) -> 'ThaiBuddhistDate': ...
    @typing.overload
    def dateNow(self, zoneId: java.time.ZoneId) -> 'ThaiBuddhistDate': ...
    @typing.overload
    def dateYearDay(self, int: int, int2: int) -> 'ThaiBuddhistDate': ...
    @typing.overload
    def dateYearDay(self, era: Era, int: int, int2: int) -> 'ThaiBuddhistDate': ...
    def eraOf(self, int: int) -> ThaiBuddhistEra: ...
    def eras(self) -> java.util.List[Era]: ...
    def getCalendarType(self) -> str: ...
    def getId(self) -> str: ...
    def isLeapYear(self, long: int) -> bool: ...
    def localDateTime(self, temporalAccessor: java.time.temporal.TemporalAccessor) -> ChronoLocalDateTime['ThaiBuddhistDate']: ...
    def prolepticYear(self, era: Era, int: int) -> int: ...
    def range(self, chronoField: java.time.temporal.ChronoField) -> java.time.temporal.ValueRange: ...
    def resolveDate(self, map: typing.Union[java.util.Map[java.time.temporal.TemporalField, int], typing.Mapping[java.time.temporal.TemporalField, int]], resolverStyle: java.time.format.ResolverStyle) -> 'ThaiBuddhistDate': ...
    @typing.overload
    def zonedDateTime(self, instant: typing.Union[java.time.Instant, datetime.datetime], zoneId: java.time.ZoneId) -> ChronoZonedDateTime['ThaiBuddhistDate']: ...
    @typing.overload
    def zonedDateTime(self, temporalAccessor: java.time.temporal.TemporalAccessor) -> ChronoZonedDateTime['ThaiBuddhistDate']: ...

class HijrahDate(java.time.chrono.ChronoLocalDateImpl['HijrahDate'], ChronoLocalDate, java.io.Serializable):
    def atTime(self, localTime: java.time.LocalTime) -> ChronoLocalDateTime['HijrahDate']: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getChronology(self) -> HijrahChronology: ...
    def getEra(self) -> HijrahEra: ...
    def getLong(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def hashCode(self) -> int: ...
    def isLeapYear(self) -> bool: ...
    def lengthOfMonth(self) -> int: ...
    def lengthOfYear(self) -> int: ...
    @typing.overload
    def minus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'HijrahDate': ...
    @typing.overload
    def minus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'HijrahDate': ...
    @typing.overload
    @staticmethod
    def now() -> 'HijrahDate': ...
    @typing.overload
    @staticmethod
    def now(clock: java.time.Clock) -> 'HijrahDate': ...
    @typing.overload
    @staticmethod
    def now(zoneId: java.time.ZoneId) -> 'HijrahDate': ...
    @staticmethod
    def of(int: int, int2: int, int3: int) -> 'HijrahDate': ...
    @typing.overload
    def plus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'HijrahDate': ...
    @typing.overload
    def plus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'HijrahDate': ...
    def range(self, temporalField: java.time.temporal.TemporalField) -> java.time.temporal.ValueRange: ...
    def toEpochDay(self) -> int: ...
    def until(self, chronoLocalDate: ChronoLocalDate) -> ChronoPeriod: ...
    def withVariant(self, hijrahChronology: HijrahChronology) -> 'HijrahDate': ...

class JapaneseDate(java.time.chrono.ChronoLocalDateImpl['JapaneseDate'], ChronoLocalDate, java.io.Serializable):
    def atTime(self, localTime: java.time.LocalTime) -> ChronoLocalDateTime['JapaneseDate']: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getChronology(self) -> JapaneseChronology: ...
    def getEra(self) -> JapaneseEra: ...
    def getLong(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def isSupported(self, temporalField: java.time.temporal.TemporalField) -> bool: ...
    @typing.overload
    def isSupported(self, temporalUnit: java.time.temporal.TemporalUnit) -> bool: ...
    def lengthOfMonth(self) -> int: ...
    def lengthOfYear(self) -> int: ...
    @typing.overload
    def minus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'JapaneseDate': ...
    @typing.overload
    def minus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'JapaneseDate': ...
    @typing.overload
    @staticmethod
    def now() -> 'JapaneseDate': ...
    @typing.overload
    @staticmethod
    def now(clock: java.time.Clock) -> 'JapaneseDate': ...
    @typing.overload
    @staticmethod
    def now(zoneId: java.time.ZoneId) -> 'JapaneseDate': ...
    @typing.overload
    @staticmethod
    def of(int: int, int2: int, int3: int) -> 'JapaneseDate': ...
    @typing.overload
    @staticmethod
    def of(japaneseEra: JapaneseEra, int: int, int2: int, int3: int) -> 'JapaneseDate': ...
    @typing.overload
    def plus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'JapaneseDate': ...
    @typing.overload
    def plus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'JapaneseDate': ...
    def range(self, temporalField: java.time.temporal.TemporalField) -> java.time.temporal.ValueRange: ...
    def toEpochDay(self) -> int: ...
    def until(self, chronoLocalDate: ChronoLocalDate) -> ChronoPeriod: ...

class MinguoDate(java.time.chrono.ChronoLocalDateImpl['MinguoDate'], ChronoLocalDate, java.io.Serializable):
    def atTime(self, localTime: java.time.LocalTime) -> ChronoLocalDateTime['MinguoDate']: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getChronology(self) -> MinguoChronology: ...
    def getEra(self) -> MinguoEra: ...
    def getLong(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def hashCode(self) -> int: ...
    def lengthOfMonth(self) -> int: ...
    @typing.overload
    def minus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'MinguoDate': ...
    @typing.overload
    def minus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'MinguoDate': ...
    @typing.overload
    @staticmethod
    def now() -> 'MinguoDate': ...
    @typing.overload
    @staticmethod
    def now(clock: java.time.Clock) -> 'MinguoDate': ...
    @typing.overload
    @staticmethod
    def now(zoneId: java.time.ZoneId) -> 'MinguoDate': ...
    @staticmethod
    def of(int: int, int2: int, int3: int) -> 'MinguoDate': ...
    @typing.overload
    def plus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'MinguoDate': ...
    @typing.overload
    def plus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'MinguoDate': ...
    def range(self, temporalField: java.time.temporal.TemporalField) -> java.time.temporal.ValueRange: ...
    def toEpochDay(self) -> int: ...
    def until(self, chronoLocalDate: ChronoLocalDate) -> ChronoPeriod: ...

class ThaiBuddhistDate(java.time.chrono.ChronoLocalDateImpl['ThaiBuddhistDate'], ChronoLocalDate, java.io.Serializable):
    def atTime(self, localTime: java.time.LocalTime) -> ChronoLocalDateTime['ThaiBuddhistDate']: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getChronology(self) -> ThaiBuddhistChronology: ...
    def getEra(self) -> ThaiBuddhistEra: ...
    def getLong(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def hashCode(self) -> int: ...
    def lengthOfMonth(self) -> int: ...
    @typing.overload
    def minus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'ThaiBuddhistDate': ...
    @typing.overload
    def minus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'ThaiBuddhistDate': ...
    @typing.overload
    @staticmethod
    def now() -> 'ThaiBuddhistDate': ...
    @typing.overload
    @staticmethod
    def now(clock: java.time.Clock) -> 'ThaiBuddhistDate': ...
    @typing.overload
    @staticmethod
    def now(zoneId: java.time.ZoneId) -> 'ThaiBuddhistDate': ...
    @staticmethod
    def of(int: int, int2: int, int3: int) -> 'ThaiBuddhistDate': ...
    @typing.overload
    def plus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'ThaiBuddhistDate': ...
    @typing.overload
    def plus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'ThaiBuddhistDate': ...
    def range(self, temporalField: java.time.temporal.TemporalField) -> java.time.temporal.ValueRange: ...
    def toEpochDay(self) -> int: ...
    def until(self, chronoLocalDate: ChronoLocalDate) -> ChronoPeriod: ...

class ChronoLocalDateImpl: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.time.chrono")``.

    AbstractChronology: typing.Type[AbstractChronology]
    ChronoLocalDate: typing.Type[ChronoLocalDate]
    ChronoLocalDateImpl: typing.Type[ChronoLocalDateImpl]
    ChronoLocalDateTime: typing.Type[ChronoLocalDateTime]
    ChronoPeriod: typing.Type[ChronoPeriod]
    ChronoZonedDateTime: typing.Type[ChronoZonedDateTime]
    Chronology: typing.Type[Chronology]
    Era: typing.Type[Era]
    HijrahChronology: typing.Type[HijrahChronology]
    HijrahDate: typing.Type[HijrahDate]
    HijrahEra: typing.Type[HijrahEra]
    IsoChronology: typing.Type[IsoChronology]
    IsoEra: typing.Type[IsoEra]
    JapaneseChronology: typing.Type[JapaneseChronology]
    JapaneseDate: typing.Type[JapaneseDate]
    JapaneseEra: typing.Type[JapaneseEra]
    MinguoChronology: typing.Type[MinguoChronology]
    MinguoDate: typing.Type[MinguoDate]
    MinguoEra: typing.Type[MinguoEra]
    ThaiBuddhistChronology: typing.Type[ThaiBuddhistChronology]
    ThaiBuddhistDate: typing.Type[ThaiBuddhistDate]
    ThaiBuddhistEra: typing.Type[ThaiBuddhistEra]



import java.lang
import java.lang.annotation
import java.lang.reflect
import java.net
import java.util
import java.util.concurrent
import okhttp3
import retrofit2.converter
import retrofit2.http
import retrofit2.internal
import typing



_Call__T = typing.TypeVar('_Call__T')  # <T>
class Call(java.lang.Cloneable, typing.Generic[_Call__T]):
    def cancel(self) -> None: ...
    def clone(self) -> 'Call'[_Call__T]: ...
    def enqueue(self, callback: 'Callback'[_Call__T]) -> None: ...
    def execute(self) -> 'Response'[_Call__T]: ...
    def isCanceled(self) -> bool: ...
    def isExecuted(self) -> bool: ...
    def request(self) -> okhttp3.Request: ...

_CallAdapter__R = typing.TypeVar('_CallAdapter__R')  # <R>
_CallAdapter__T = typing.TypeVar('_CallAdapter__T')  # <T>
class CallAdapter(typing.Generic[_CallAdapter__R, _CallAdapter__T]):
    def adapt(self, call: Call[_CallAdapter__R]) -> _CallAdapter__T: ...
    def responseType(self) -> java.lang.reflect.Type: ...
    class Factory:
        def __init__(self): ...
        def get(self, type: java.lang.reflect.Type, annotationArray: typing.List[java.lang.annotation.Annotation], retrofit: 'Retrofit') -> 'CallAdapter'[typing.Any, typing.Any]: ...

_Callback__T = typing.TypeVar('_Callback__T')  # <T>
class Callback(typing.Generic[_Callback__T]):
    def onFailure(self, call: Call[_Callback__T], throwable: java.lang.Throwable) -> None: ...
    def onResponse(self, call: Call[_Callback__T], response: 'Response'[_Callback__T]) -> None: ...

_Converter__F = typing.TypeVar('_Converter__F')  # <F>
_Converter__T = typing.TypeVar('_Converter__T')  # <T>
class Converter(typing.Generic[_Converter__F, _Converter__T]):
    def convert(self, f: _Converter__F) -> _Converter__T: ...
    class Factory:
        def __init__(self): ...
        def requestBodyConverter(self, type: java.lang.reflect.Type, annotationArray: typing.List[java.lang.annotation.Annotation], annotationArray2: typing.List[java.lang.annotation.Annotation], retrofit: 'Retrofit') -> 'Converter'[typing.Any, okhttp3.RequestBody]: ...
        def responseBodyConverter(self, type: java.lang.reflect.Type, annotationArray: typing.List[java.lang.annotation.Annotation], retrofit: 'Retrofit') -> 'Converter'[okhttp3.ResponseBody, typing.Any]: ...
        def stringConverter(self, type: java.lang.reflect.Type, annotationArray: typing.List[java.lang.annotation.Annotation], retrofit: 'Retrofit') -> 'Converter'[typing.Any, str]: ...

class HttpException(java.lang.RuntimeException):
    def __init__(self, response: 'Response'[typing.Any]): ...
    def code(self) -> int: ...
    def message(self) -> str: ...
    def response(self) -> 'Response'[typing.Any]: ...

class Invocation:
    def arguments(self) -> java.util.List[typing.Any]: ...
    def method(self) -> java.lang.reflect.Method: ...
    @staticmethod
    def of(method: java.lang.reflect.Method, list: java.util.List[typing.Any]) -> 'Invocation': ...
    def toString(self) -> str: ...

_Response__T = typing.TypeVar('_Response__T')  # <T>
class Response(typing.Generic[_Response__T]):
    def body(self) -> _Response__T: ...
    def code(self) -> int: ...
    _error_0__T = typing.TypeVar('_error_0__T')  # <T>
    _error_1__T = typing.TypeVar('_error_1__T')  # <T>
    @typing.overload
    @staticmethod
    def error(int: int, responseBody: okhttp3.ResponseBody) -> 'Response'[_error_0__T]: ...
    @typing.overload
    @staticmethod
    def error(responseBody: okhttp3.ResponseBody, response2: okhttp3.Response) -> 'Response'[_error_1__T]: ...
    def errorBody(self) -> okhttp3.ResponseBody: ...
    def headers(self) -> okhttp3.Headers: ...
    def isSuccessful(self) -> bool: ...
    def message(self) -> str: ...
    def raw(self) -> okhttp3.Response: ...
    _success_0__T = typing.TypeVar('_success_0__T')  # <T>
    _success_1__T = typing.TypeVar('_success_1__T')  # <T>
    _success_2__T = typing.TypeVar('_success_2__T')  # <T>
    _success_3__T = typing.TypeVar('_success_3__T')  # <T>
    @typing.overload
    @staticmethod
    def success(int: int, t: _success_0__T) -> 'Response'[_success_0__T]: ...
    @typing.overload
    @staticmethod
    def success(t: _success_1__T) -> 'Response'[_success_1__T]: ...
    @typing.overload
    @staticmethod
    def success(t: _success_2__T, headers: okhttp3.Headers) -> 'Response'[_success_2__T]: ...
    @typing.overload
    @staticmethod
    def success(t: _success_3__T, response: okhttp3.Response) -> 'Response'[_success_3__T]: ...
    def toString(self) -> str: ...

class Retrofit:
    def baseUrl(self) -> okhttp3.HttpUrl: ...
    def callAdapter(self, type: java.lang.reflect.Type, annotationArray: typing.List[java.lang.annotation.Annotation]) -> CallAdapter[typing.Any, typing.Any]: ...
    def callAdapterFactories(self) -> java.util.List[CallAdapter.Factory]: ...
    def callFactory(self) -> okhttp3.Call.Factory: ...
    def callbackExecutor(self) -> java.util.concurrent.Executor: ...
    def converterFactories(self) -> java.util.List[Converter.Factory]: ...
    _create__T = typing.TypeVar('_create__T')  # <T>
    def create(self, class_: typing.Type[_create__T]) -> _create__T: ...
    def newBuilder(self) -> 'Retrofit.Builder': ...
    def nextCallAdapter(self, factory: CallAdapter.Factory, type: java.lang.reflect.Type, annotationArray: typing.List[java.lang.annotation.Annotation]) -> CallAdapter[typing.Any, typing.Any]: ...
    _nextRequestBodyConverter__T = typing.TypeVar('_nextRequestBodyConverter__T')  # <T>
    def nextRequestBodyConverter(self, factory: Converter.Factory, type: java.lang.reflect.Type, annotationArray: typing.List[java.lang.annotation.Annotation], annotationArray2: typing.List[java.lang.annotation.Annotation]) -> Converter[_nextRequestBodyConverter__T, okhttp3.RequestBody]: ...
    _nextResponseBodyConverter__T = typing.TypeVar('_nextResponseBodyConverter__T')  # <T>
    def nextResponseBodyConverter(self, factory: Converter.Factory, type: java.lang.reflect.Type, annotationArray: typing.List[java.lang.annotation.Annotation]) -> Converter[okhttp3.ResponseBody, _nextResponseBodyConverter__T]: ...
    _requestBodyConverter__T = typing.TypeVar('_requestBodyConverter__T')  # <T>
    def requestBodyConverter(self, type: java.lang.reflect.Type, annotationArray: typing.List[java.lang.annotation.Annotation], annotationArray2: typing.List[java.lang.annotation.Annotation]) -> Converter[_requestBodyConverter__T, okhttp3.RequestBody]: ...
    _responseBodyConverter__T = typing.TypeVar('_responseBodyConverter__T')  # <T>
    def responseBodyConverter(self, type: java.lang.reflect.Type, annotationArray: typing.List[java.lang.annotation.Annotation]) -> Converter[okhttp3.ResponseBody, _responseBodyConverter__T]: ...
    _stringConverter__T = typing.TypeVar('_stringConverter__T')  # <T>
    def stringConverter(self, type: java.lang.reflect.Type, annotationArray: typing.List[java.lang.annotation.Annotation]) -> Converter[_stringConverter__T, str]: ...
    class Builder:
        def __init__(self): ...
        def addCallAdapterFactory(self, factory: CallAdapter.Factory) -> 'Retrofit.Builder': ...
        def addConverterFactory(self, factory: Converter.Factory) -> 'Retrofit.Builder': ...
        @typing.overload
        def baseUrl(self, string: str) -> 'Retrofit.Builder': ...
        @typing.overload
        def baseUrl(self, uRL: java.net.URL) -> 'Retrofit.Builder': ...
        @typing.overload
        def baseUrl(self, httpUrl: okhttp3.HttpUrl) -> 'Retrofit.Builder': ...
        def build(self) -> 'Retrofit': ...
        def callAdapterFactories(self) -> java.util.List[CallAdapter.Factory]: ...
        def callFactory(self, factory: okhttp3.Call.Factory) -> 'Retrofit.Builder': ...
        def callbackExecutor(self, executor: java.util.concurrent.Executor) -> 'Retrofit.Builder': ...
        def client(self, okHttpClient: okhttp3.OkHttpClient) -> 'Retrofit.Builder': ...
        def converterFactories(self) -> java.util.List[Converter.Factory]: ...
        def validateEagerly(self, boolean: bool) -> 'Retrofit.Builder': ...

class RetrofitUtil:
    def __init__(self): ...
    _invokeServiceMethod__T = typing.TypeVar('_invokeServiceMethod__T')  # <T>
    @staticmethod
    def invokeServiceMethod(retrofit: Retrofit, method: java.lang.reflect.Method, objectArray: typing.List[typing.Any]) -> Call[_invokeServiceMethod__T]: ...

class SkipCallbackExecutor(java.lang.annotation.Annotation):
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("retrofit2")``.

    Call: typing.Type[Call]
    CallAdapter: typing.Type[CallAdapter]
    Callback: typing.Type[Callback]
    Converter: typing.Type[Converter]
    HttpException: typing.Type[HttpException]
    Invocation: typing.Type[Invocation]
    Response: typing.Type[Response]
    Retrofit: typing.Type[Retrofit]
    RetrofitUtil: typing.Type[RetrofitUtil]
    SkipCallbackExecutor: typing.Type[SkipCallbackExecutor]
    converter: retrofit2.converter.__module_protocol__
    http: retrofit2.http.__module_protocol__
    internal: retrofit2.internal.__module_protocol__



import java.lang
import java.util.concurrent
import java.util.concurrent.atomic
import java.util.concurrent.locks
import scala
import scala.concurrent
import scala.concurrent.duration
import scala.reflect
import scala.runtime
import scala.util
import typing



_CallbackRunnable__T = typing.TypeVar('_CallbackRunnable__T')  # <T>
class CallbackRunnable(java.lang.Runnable, scala.concurrent.OnCompleteRunnable, typing.Generic[_CallbackRunnable__T]):
    def __init__(self, executor: scala.concurrent.ExecutionContext, onComplete: scala.Function1[scala.util.Try[_CallbackRunnable__T], typing.Any]): ...
    def executeWithValue(self, v: scala.util.Try[_CallbackRunnable__T]) -> None: ...
    def executor(self) -> scala.concurrent.ExecutionContext: ...
    def onComplete(self) -> scala.Function1[scala.util.Try[_CallbackRunnable__T], typing.Any]: ...
    def run(self) -> None: ...
    def value(self) -> scala.util.Try[_CallbackRunnable__T]: ...
    def value_$eq(self, x$1: scala.util.Try[_CallbackRunnable__T]) -> None: ...

class ExecutionContextImpl(scala.concurrent.ExecutionContextExecutor):
    def __init__(self, executor: java.util.concurrent.Executor, reporter: scala.Function1[java.lang.Throwable, scala.runtime.BoxedUnit]): ...
    @staticmethod
    def createDefaultExecutorService(reporter: scala.Function1[java.lang.Throwable, scala.runtime.BoxedUnit]) -> java.util.concurrent.ExecutorService: ...
    def execute(self, runnable: typing.Union[java.lang.Runnable, typing.Callable]) -> None: ...
    def executor(self) -> java.util.concurrent.Executor: ...
    @staticmethod
    def fromExecutor(e: java.util.concurrent.Executor, reporter: scala.Function1[java.lang.Throwable, scala.runtime.BoxedUnit]) -> 'ExecutionContextImpl': ...
    @staticmethod
    def fromExecutor$default$2() -> scala.Function1[java.lang.Throwable, scala.runtime.BoxedUnit]: ...
    @staticmethod
    def fromExecutorService(es: java.util.concurrent.ExecutorService, reporter: scala.Function1[java.lang.Throwable, scala.runtime.BoxedUnit]) -> 'ExecutionContextImpl': ...
    @staticmethod
    def fromExecutorService$default$2() -> scala.Function1[java.lang.Throwable, scala.runtime.BoxedUnit]: ...
    def prepare(self) -> scala.concurrent.ExecutionContext: ...
    def reportFailure(self, t: java.lang.Throwable) -> None: ...
    def reporter(self) -> scala.Function1[java.lang.Throwable, scala.runtime.BoxedUnit]: ...
    class DefaultThreadFactory(java.util.concurrent.ThreadFactory, java.util.concurrent.ForkJoinPool.ForkJoinWorkerThreadFactory):
        def __init__(self, daemonic: bool, maxBlockers: int, prefix: typing.Union[java.lang.String, str], uncaught: typing.Union[java.lang.Thread.UncaughtExceptionHandler, typing.Callable]): ...
        @typing.overload
        def newThread(self, runnable: typing.Union[java.lang.Runnable, typing.Callable]) -> java.lang.Thread: ...
        @typing.overload
        def newThread(self, fjp: java.util.concurrent.ForkJoinPool) -> java.util.concurrent.ForkJoinWorkerThread: ...
        def scala$concurrent$impl$ExecutionContextImpl$DefaultThreadFactory$$freeBlocker(self) -> bool: ...
        def scala$concurrent$impl$ExecutionContextImpl$DefaultThreadFactory$$newBlocker(self) -> bool: ...
        _wire__T = typing.TypeVar('_wire__T', bound=java.lang.Thread)  # <T>
        def wire(self, thread: _wire__T) -> _wire__T: ...

_Promise__CompletionLatch__T = typing.TypeVar('_Promise__CompletionLatch__T')  # <T>
_Promise__DefaultPromise__T = typing.TypeVar('_Promise__DefaultPromise__T')  # <T>
_Promise__KeptPromise__Failed__T = typing.TypeVar('_Promise__KeptPromise__Failed__T')  # <T>
_Promise__KeptPromise__Kept__T = typing.TypeVar('_Promise__KeptPromise__Kept__T')  # <T>
_Promise__KeptPromise__Successful__T = typing.TypeVar('_Promise__KeptPromise__Successful__T')  # <T>
_Promise__T = typing.TypeVar('_Promise__T')  # <T>
class Promise(scala.concurrent.Promise[_Promise__T], scala.concurrent.Future[_Promise__T], typing.Generic[_Promise__T]):
    @staticmethod
    def $init$($this: 'Promise') -> None: ...
    @typing.overload
    def future(self) -> scala.concurrent.Future[_Promise__T]: ...
    @typing.overload
    def future(self) -> 'Promise'[_Promise__T]: ...
    def toString(self) -> java.lang.String: ...
    _transform_0__S = typing.TypeVar('_transform_0__S')  # <S>
    _transform_1__S = typing.TypeVar('_transform_1__S')  # <S>
    @typing.overload
    def transform(self, s: scala.Function1[_Promise__T, _transform_0__S], f: scala.Function1[java.lang.Throwable, java.lang.Throwable], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_transform_0__S]: ...
    @typing.overload
    def transform(self, f: scala.Function1[scala.util.Try[_Promise__T], scala.util.Try[_transform_1__S]], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_transform_1__S]: ...
    _transformWith__S = typing.TypeVar('_transformWith__S')  # <S>
    def transformWith(self, f: scala.Function1[scala.util.Try[_Promise__T], scala.concurrent.Future[_transformWith__S]], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_transformWith__S]: ...
    class CompletionLatch(java.util.concurrent.locks.AbstractQueuedSynchronizer, scala.Function1[scala.util.Try[_Promise__CompletionLatch__T], scala.runtime.BoxedUnit], typing.Generic[_Promise__CompletionLatch__T]):
        def __init__(self): ...
        _andThen__A = typing.TypeVar('_andThen__A')  # <A>
        def andThen(self, g: scala.Function1[scala.runtime.BoxedUnit, _andThen__A]) -> scala.Function1[scala.util.Try[_Promise__CompletionLatch__T], _andThen__A]: ...
        def apply(self, ignored: scala.util.Try[_Promise__CompletionLatch__T]) -> None: ...
        def apply$mcDD$sp(self, v1: float) -> float: ...
        def apply$mcDF$sp(self, v1: float) -> float: ...
        def apply$mcDI$sp(self, v1: int) -> float: ...
        def apply$mcDJ$sp(self, v1: int) -> float: ...
        def apply$mcFD$sp(self, v1: float) -> float: ...
        def apply$mcFF$sp(self, v1: float) -> float: ...
        def apply$mcFI$sp(self, v1: int) -> float: ...
        def apply$mcFJ$sp(self, v1: int) -> float: ...
        def apply$mcID$sp(self, v1: float) -> int: ...
        def apply$mcIF$sp(self, v1: float) -> int: ...
        def apply$mcII$sp(self, v1: int) -> int: ...
        def apply$mcIJ$sp(self, v1: int) -> int: ...
        def apply$mcJD$sp(self, v1: float) -> int: ...
        def apply$mcJF$sp(self, v1: float) -> int: ...
        def apply$mcJI$sp(self, v1: int) -> int: ...
        def apply$mcJJ$sp(self, v1: int) -> int: ...
        def apply$mcVD$sp(self, v1: float) -> None: ...
        def apply$mcVF$sp(self, v1: float) -> None: ...
        def apply$mcVI$sp(self, v1: int) -> None: ...
        def apply$mcVJ$sp(self, v1: int) -> None: ...
        def apply$mcZD$sp(self, v1: float) -> bool: ...
        def apply$mcZF$sp(self, v1: float) -> bool: ...
        def apply$mcZI$sp(self, v1: int) -> bool: ...
        def apply$mcZJ$sp(self, v1: int) -> bool: ...
        _compose__A = typing.TypeVar('_compose__A')  # <A>
        def compose(self, g: scala.Function1[_compose__A, scala.util.Try[_Promise__CompletionLatch__T]]) -> scala.Function1[_compose__A, scala.runtime.BoxedUnit]: ...
        def toString(self) -> java.lang.String: ...
        def tryAcquireShared(self, ignored: int) -> int: ...
        def tryReleaseShared(self, ignore: int) -> bool: ...
    class DefaultPromise(java.util.concurrent.atomic.AtomicReference[typing.Any], scala.concurrent.impl.Promise[_Promise__DefaultPromise__T], typing.Generic[_Promise__DefaultPromise__T]):
        def __init__(self): ...
        _andThen__U = typing.TypeVar('_andThen__U')  # <U>
        def andThen(self, pf: scala.PartialFunction[scala.util.Try[_Promise__DefaultPromise__T], _andThen__U], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_Promise__DefaultPromise__T]: ...
        _collect__S = typing.TypeVar('_collect__S')  # <S>
        def collect(self, pf: scala.PartialFunction[_Promise__DefaultPromise__T, _collect__S], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_collect__S]: ...
        def complete(self, result: scala.util.Try[_Promise__DefaultPromise__T]) -> scala.concurrent.Promise[_Promise__DefaultPromise__T]: ...
        def completeWith(self, other: scala.concurrent.Future[_Promise__DefaultPromise__T]) -> scala.concurrent.Promise[_Promise__DefaultPromise__T]: ...
        def failed(self) -> scala.concurrent.Future[java.lang.Throwable]: ...
        def failure(self, cause: java.lang.Throwable) -> scala.concurrent.Promise[_Promise__DefaultPromise__T]: ...
        _fallbackTo__U = typing.TypeVar('_fallbackTo__U')  # <U>
        def fallbackTo(self, that: scala.concurrent.Future[_fallbackTo__U]) -> scala.concurrent.Future[_fallbackTo__U]: ...
        def filter(self, p: scala.Function1[_Promise__DefaultPromise__T, typing.Any], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_Promise__DefaultPromise__T]: ...
        _flatMap__S = typing.TypeVar('_flatMap__S')  # <S>
        def flatMap(self, f: scala.Function1[_Promise__DefaultPromise__T, scala.concurrent.Future[_flatMap__S]], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_flatMap__S]: ...
        _flatten__S = typing.TypeVar('_flatten__S')  # <S>
        def flatten(self, ev: scala.Predef..less.colon.less[_Promise__DefaultPromise__T, scala.concurrent.Future[_flatten__S]]) -> scala.concurrent.Future[_flatten__S]: ...
        _foreach__U = typing.TypeVar('_foreach__U')  # <U>
        def foreach(self, f: scala.Function1[_Promise__DefaultPromise__T, _foreach__U], executor: scala.concurrent.ExecutionContext) -> None: ...
        def future(self) -> 'Promise'[_Promise__DefaultPromise__T]: ...
        def isCompleted(self) -> bool: ...
        def linkRootOf(self, target: 'Promise.DefaultPromise'[_Promise__DefaultPromise__T]) -> None: ...
        _map__S = typing.TypeVar('_map__S')  # <S>
        def map(self, f: scala.Function1[_Promise__DefaultPromise__T, _map__S], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_map__S]: ...
        _mapTo__S = typing.TypeVar('_mapTo__S')  # <S>
        def mapTo(self, tag: scala.reflect.ClassTag[_mapTo__S]) -> scala.concurrent.Future[_mapTo__S]: ...
        _onComplete__U = typing.TypeVar('_onComplete__U')  # <U>
        def onComplete(self, func: scala.Function1[scala.util.Try[_Promise__DefaultPromise__T], _onComplete__U], executor: scala.concurrent.ExecutionContext) -> None: ...
        _onFailure__U = typing.TypeVar('_onFailure__U')  # <U>
        def onFailure(self, pf: scala.PartialFunction[java.lang.Throwable, _onFailure__U], executor: scala.concurrent.ExecutionContext) -> None: ...
        _onSuccess__U = typing.TypeVar('_onSuccess__U')  # <U>
        def onSuccess(self, pf: scala.PartialFunction[_Promise__DefaultPromise__T, _onSuccess__U], executor: scala.concurrent.ExecutionContext) -> None: ...
        def ready(self, atMost: scala.concurrent.duration.Duration, permit: scala.concurrent.CanAwait) -> 'Promise.DefaultPromise'[_Promise__DefaultPromise__T]: ...
        _recover__U = typing.TypeVar('_recover__U')  # <U>
        def recover(self, pf: scala.PartialFunction[java.lang.Throwable, _recover__U], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_recover__U]: ...
        _recoverWith__U = typing.TypeVar('_recoverWith__U')  # <U>
        def recoverWith(self, pf: scala.PartialFunction[java.lang.Throwable, scala.concurrent.Future[_recoverWith__U]], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_recoverWith__U]: ...
        def result(self, atMost: scala.concurrent.duration.Duration, permit: scala.concurrent.CanAwait) -> _Promise__DefaultPromise__T: ...
        def success(self, value: _Promise__DefaultPromise__T) -> scala.concurrent.Promise[_Promise__DefaultPromise__T]: ...
        def toString(self) -> java.lang.String: ...
        _transform_0__S = typing.TypeVar('_transform_0__S')  # <S>
        _transform_1__S = typing.TypeVar('_transform_1__S')  # <S>
        @typing.overload
        def transform(self, s: scala.Function1[_Promise__DefaultPromise__T, _transform_0__S], f: scala.Function1[java.lang.Throwable, java.lang.Throwable], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_transform_0__S]: ...
        @typing.overload
        def transform(self, f: scala.Function1[scala.util.Try[_Promise__DefaultPromise__T], scala.util.Try[_transform_1__S]], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_transform_1__S]: ...
        _transformWith__S = typing.TypeVar('_transformWith__S')  # <S>
        def transformWith(self, f: scala.Function1[scala.util.Try[_Promise__DefaultPromise__T], scala.concurrent.Future[_transformWith__S]], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_transformWith__S]: ...
        def tryAwait(self, atMost: scala.concurrent.duration.Duration) -> bool: ...
        def tryComplete(self, value: scala.util.Try[_Promise__DefaultPromise__T]) -> bool: ...
        def tryCompleteWith(self, other: scala.concurrent.Future[_Promise__DefaultPromise__T]) -> scala.concurrent.Promise[_Promise__DefaultPromise__T]: ...
        def tryFailure(self, cause: java.lang.Throwable) -> bool: ...
        def trySuccess(self, value: _Promise__DefaultPromise__T) -> bool: ...
        def value(self) -> scala.Option[scala.util.Try[_Promise__DefaultPromise__T]]: ...
        def withFilter(self, p: scala.Function1[_Promise__DefaultPromise__T, typing.Any], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_Promise__DefaultPromise__T]: ...
        _zip__U = typing.TypeVar('_zip__U')  # <U>
        def zip(self, that: scala.concurrent.Future[_zip__U]) -> scala.concurrent.Future[scala.Tuple2[_Promise__DefaultPromise__T, _zip__U]]: ...
        _zipWith__U = typing.TypeVar('_zipWith__U')  # <U>
        _zipWith__R = typing.TypeVar('_zipWith__R')  # <R>
        def zipWith(self, that: scala.concurrent.Future[_zipWith__U], f: scala.Function2[_Promise__DefaultPromise__T, _zipWith__U, _zipWith__R], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_zipWith__R]: ...
    class KeptPromise$:
        MODULE$: typing.ClassVar['Promise.KeptPromise.'] = ...
        def __init__(self): ...
        _apply__T = typing.TypeVar('_apply__T')  # <T>
        def apply(self, result: scala.util.Try[_apply__T]) -> scala.concurrent.Promise[_apply__T]: ...
        class Failed(scala.concurrent.impl.Promise.KeptPromise.Kept[_Promise__KeptPromise__Failed__T], typing.Generic[_Promise__KeptPromise__Failed__T]):
            def __init__(self, result: scala.util.Failure[_Promise__KeptPromise__Failed__T]): ...
            _andThen__U = typing.TypeVar('_andThen__U')  # <U>
            def andThen(self, pf: scala.PartialFunction[scala.util.Try[_Promise__KeptPromise__Failed__T], _andThen__U], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_Promise__KeptPromise__Failed__T]: ...
            _collect__S = typing.TypeVar('_collect__S')  # <S>
            def collect(self, pf: scala.PartialFunction[_Promise__KeptPromise__Failed__T, _collect__S], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_collect__S]: ...
            def complete(self, result: scala.util.Try[_Promise__KeptPromise__Failed__T]) -> scala.concurrent.Promise[_Promise__KeptPromise__Failed__T]: ...
            def completeWith(self, other: scala.concurrent.Future[_Promise__KeptPromise__Failed__T]) -> scala.concurrent.Promise[_Promise__KeptPromise__Failed__T]: ...
            def failed(self) -> scala.concurrent.Future[java.lang.Throwable]: ...
            def failure(self, cause: java.lang.Throwable) -> scala.concurrent.Promise[_Promise__KeptPromise__Failed__T]: ...
            _fallbackTo__U = typing.TypeVar('_fallbackTo__U')  # <U>
            def fallbackTo(self, that: scala.concurrent.Future[_fallbackTo__U]) -> scala.concurrent.Future[_fallbackTo__U]: ...
            def filter(self, p: scala.Function1[_Promise__KeptPromise__Failed__T, typing.Any], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_Promise__KeptPromise__Failed__T]: ...
            _flatMap__S = typing.TypeVar('_flatMap__S')  # <S>
            def flatMap(self, f: scala.Function1[_Promise__KeptPromise__Failed__T, scala.concurrent.Future[_flatMap__S]], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_flatMap__S]: ...
            _flatten__S = typing.TypeVar('_flatten__S')  # <S>
            def flatten(self, ev: scala.Predef..less.colon.less[_Promise__KeptPromise__Failed__T, scala.concurrent.Future[_flatten__S]]) -> scala.concurrent.Future[_flatten__S]: ...
            _foreach__U = typing.TypeVar('_foreach__U')  # <U>
            def foreach(self, f: scala.Function1[_Promise__KeptPromise__Failed__T, _foreach__U], executor: scala.concurrent.ExecutionContext) -> None: ...
            def future(self) -> 'Promise'[_Promise__KeptPromise__Failed__T]: ...
            def isCompleted(self) -> bool: ...
            _map__S = typing.TypeVar('_map__S')  # <S>
            def map(self, f: scala.Function1[_Promise__KeptPromise__Failed__T, _map__S], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_map__S]: ...
            _mapTo__S = typing.TypeVar('_mapTo__S')  # <S>
            def mapTo(self, tag: scala.reflect.ClassTag[_mapTo__S]) -> scala.concurrent.Future[_mapTo__S]: ...
            _onComplete__U = typing.TypeVar('_onComplete__U')  # <U>
            def onComplete(self, func: scala.Function1[scala.util.Try[_Promise__KeptPromise__Failed__T], _onComplete__U], executor: scala.concurrent.ExecutionContext) -> None: ...
            _onFailure__U = typing.TypeVar('_onFailure__U')  # <U>
            def onFailure(self, pf: scala.PartialFunction[java.lang.Throwable, _onFailure__U], executor: scala.concurrent.ExecutionContext) -> None: ...
            _onSuccess__U = typing.TypeVar('_onSuccess__U')  # <U>
            def onSuccess(self, pf: scala.PartialFunction[_Promise__KeptPromise__Failed__T, _onSuccess__U], executor: scala.concurrent.ExecutionContext) -> None: ...
            def ready(self, atMost: scala.concurrent.duration.Duration, permit: scala.concurrent.CanAwait) -> 'Promise.KeptPromise.Kept'[_Promise__KeptPromise__Failed__T]: ...
            _recover__U = typing.TypeVar('_recover__U')  # <U>
            def recover(self, pf: scala.PartialFunction[java.lang.Throwable, _recover__U], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_recover__U]: ...
            _recoverWith__U = typing.TypeVar('_recoverWith__U')  # <U>
            def recoverWith(self, pf: scala.PartialFunction[java.lang.Throwable, scala.concurrent.Future[_recoverWith__U]], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_recoverWith__U]: ...
            @typing.overload
            def result(self, atMost: scala.concurrent.duration.Duration, permit: scala.concurrent.CanAwait) -> _Promise__KeptPromise__Failed__T: ...
            @typing.overload
            def result(self) -> scala.util.Failure[_Promise__KeptPromise__Failed__T]: ...
            def success(self, value: _Promise__KeptPromise__Failed__T) -> scala.concurrent.Promise[_Promise__KeptPromise__Failed__T]: ...
            def toString(self) -> java.lang.String: ...
            _transform_0__S = typing.TypeVar('_transform_0__S')  # <S>
            _transform_1__S = typing.TypeVar('_transform_1__S')  # <S>
            @typing.overload
            def transform(self, s: scala.Function1[_Promise__KeptPromise__Failed__T, _transform_0__S], f: scala.Function1[java.lang.Throwable, java.lang.Throwable], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_transform_0__S]: ...
            @typing.overload
            def transform(self, f: scala.Function1[scala.util.Try[_Promise__KeptPromise__Failed__T], scala.util.Try[_transform_1__S]], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_transform_1__S]: ...
            _transformWith__S = typing.TypeVar('_transformWith__S')  # <S>
            def transformWith(self, f: scala.Function1[scala.util.Try[_Promise__KeptPromise__Failed__T], scala.concurrent.Future[_transformWith__S]], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_transformWith__S]: ...
            def tryComplete(self, value: scala.util.Try[_Promise__KeptPromise__Failed__T]) -> bool: ...
            def tryCompleteWith(self, other: scala.concurrent.Future[_Promise__KeptPromise__Failed__T]) -> scala.concurrent.Promise[_Promise__KeptPromise__Failed__T]: ...
            def tryFailure(self, cause: java.lang.Throwable) -> bool: ...
            def trySuccess(self, value: _Promise__KeptPromise__Failed__T) -> bool: ...
            def value(self) -> scala.Option[scala.util.Try[_Promise__KeptPromise__Failed__T]]: ...
            def withFilter(self, p: scala.Function1[_Promise__KeptPromise__Failed__T, typing.Any], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_Promise__KeptPromise__Failed__T]: ...
            _zip__U = typing.TypeVar('_zip__U')  # <U>
            def zip(self, that: scala.concurrent.Future[_zip__U]) -> scala.concurrent.Future[scala.Tuple2[_Promise__KeptPromise__Failed__T, _zip__U]]: ...
            _zipWith__U = typing.TypeVar('_zipWith__U')  # <U>
            _zipWith__R = typing.TypeVar('_zipWith__R')  # <R>
            def zipWith(self, that: scala.concurrent.Future[_zipWith__U], f: scala.Function2[_Promise__KeptPromise__Failed__T, _zipWith__U, _zipWith__R], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_zipWith__R]: ...
        class Kept(scala.concurrent.impl.Promise[_Promise__KeptPromise__Kept__T], typing.Generic[_Promise__KeptPromise__Kept__T]):
            @staticmethod
            def $init$($this: 'Promise.KeptPromise.Kept') -> None: ...
            def isCompleted(self) -> bool: ...
            _onComplete__U = typing.TypeVar('_onComplete__U')  # <U>
            def onComplete(self, func: scala.Function1[scala.util.Try[_Promise__KeptPromise__Kept__T], _onComplete__U], executor: scala.concurrent.ExecutionContext) -> None: ...
            @typing.overload
            def ready(self, atMost: scala.concurrent.duration.Duration, permit: scala.concurrent.CanAwait) -> scala.concurrent.Awaitable[_Promise__KeptPromise__Kept__T]: ...
            @typing.overload
            def ready(self, atMost: scala.concurrent.duration.Duration, permit: scala.concurrent.CanAwait) -> 'Promise.KeptPromise.Kept'[_Promise__KeptPromise__Kept__T]: ...
            @typing.overload
            def result(self) -> scala.util.Try[_Promise__KeptPromise__Kept__T]: ...
            @typing.overload
            def result(self, atMost: scala.concurrent.duration.Duration, permit: scala.concurrent.CanAwait) -> _Promise__KeptPromise__Kept__T: ...
            def toString(self) -> java.lang.String: ...
            def tryComplete(self, value: scala.util.Try[_Promise__KeptPromise__Kept__T]) -> bool: ...
            def value(self) -> scala.Option[scala.util.Try[_Promise__KeptPromise__Kept__T]]: ...
        class Successful(scala.concurrent.impl.Promise.KeptPromise.Kept[_Promise__KeptPromise__Successful__T], typing.Generic[_Promise__KeptPromise__Successful__T]):
            def __init__(self, result: scala.util.Success[_Promise__KeptPromise__Successful__T]): ...
            _andThen__U = typing.TypeVar('_andThen__U')  # <U>
            def andThen(self, pf: scala.PartialFunction[scala.util.Try[_Promise__KeptPromise__Successful__T], _andThen__U], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_Promise__KeptPromise__Successful__T]: ...
            _collect__S = typing.TypeVar('_collect__S')  # <S>
            def collect(self, pf: scala.PartialFunction[_Promise__KeptPromise__Successful__T, _collect__S], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_collect__S]: ...
            def complete(self, result: scala.util.Try[_Promise__KeptPromise__Successful__T]) -> scala.concurrent.Promise[_Promise__KeptPromise__Successful__T]: ...
            def completeWith(self, other: scala.concurrent.Future[_Promise__KeptPromise__Successful__T]) -> scala.concurrent.Promise[_Promise__KeptPromise__Successful__T]: ...
            def failed(self) -> scala.concurrent.Future[java.lang.Throwable]: ...
            def failure(self, cause: java.lang.Throwable) -> scala.concurrent.Promise[_Promise__KeptPromise__Successful__T]: ...
            _fallbackTo__U = typing.TypeVar('_fallbackTo__U')  # <U>
            def fallbackTo(self, that: scala.concurrent.Future[_fallbackTo__U]) -> scala.concurrent.Future[_fallbackTo__U]: ...
            def filter(self, p: scala.Function1[_Promise__KeptPromise__Successful__T, typing.Any], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_Promise__KeptPromise__Successful__T]: ...
            _flatMap__S = typing.TypeVar('_flatMap__S')  # <S>
            def flatMap(self, f: scala.Function1[_Promise__KeptPromise__Successful__T, scala.concurrent.Future[_flatMap__S]], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_flatMap__S]: ...
            _flatten__S = typing.TypeVar('_flatten__S')  # <S>
            def flatten(self, ev: scala.Predef..less.colon.less[_Promise__KeptPromise__Successful__T, scala.concurrent.Future[_flatten__S]]) -> scala.concurrent.Future[_flatten__S]: ...
            _foreach__U = typing.TypeVar('_foreach__U')  # <U>
            def foreach(self, f: scala.Function1[_Promise__KeptPromise__Successful__T, _foreach__U], executor: scala.concurrent.ExecutionContext) -> None: ...
            def future(self) -> 'Promise'[_Promise__KeptPromise__Successful__T]: ...
            def isCompleted(self) -> bool: ...
            _map__S = typing.TypeVar('_map__S')  # <S>
            def map(self, f: scala.Function1[_Promise__KeptPromise__Successful__T, _map__S], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_map__S]: ...
            _mapTo__S = typing.TypeVar('_mapTo__S')  # <S>
            def mapTo(self, tag: scala.reflect.ClassTag[_mapTo__S]) -> scala.concurrent.Future[_mapTo__S]: ...
            _onComplete__U = typing.TypeVar('_onComplete__U')  # <U>
            def onComplete(self, func: scala.Function1[scala.util.Try[_Promise__KeptPromise__Successful__T], _onComplete__U], executor: scala.concurrent.ExecutionContext) -> None: ...
            _onFailure__U = typing.TypeVar('_onFailure__U')  # <U>
            def onFailure(self, pf: scala.PartialFunction[java.lang.Throwable, _onFailure__U], executor: scala.concurrent.ExecutionContext) -> None: ...
            _onSuccess__U = typing.TypeVar('_onSuccess__U')  # <U>
            def onSuccess(self, pf: scala.PartialFunction[_Promise__KeptPromise__Successful__T, _onSuccess__U], executor: scala.concurrent.ExecutionContext) -> None: ...
            def ready(self, atMost: scala.concurrent.duration.Duration, permit: scala.concurrent.CanAwait) -> 'Promise.KeptPromise.Kept'[_Promise__KeptPromise__Successful__T]: ...
            _recover__U = typing.TypeVar('_recover__U')  # <U>
            def recover(self, pf: scala.PartialFunction[java.lang.Throwable, _recover__U], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_recover__U]: ...
            _recoverWith__U = typing.TypeVar('_recoverWith__U')  # <U>
            def recoverWith(self, pf: scala.PartialFunction[java.lang.Throwable, scala.concurrent.Future[_recoverWith__U]], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_recoverWith__U]: ...
            @typing.overload
            def result(self, atMost: scala.concurrent.duration.Duration, permit: scala.concurrent.CanAwait) -> _Promise__KeptPromise__Successful__T: ...
            @typing.overload
            def result(self) -> scala.util.Success[_Promise__KeptPromise__Successful__T]: ...
            def success(self, value: _Promise__KeptPromise__Successful__T) -> scala.concurrent.Promise[_Promise__KeptPromise__Successful__T]: ...
            def toString(self) -> java.lang.String: ...
            _transform_0__S = typing.TypeVar('_transform_0__S')  # <S>
            _transform_1__S = typing.TypeVar('_transform_1__S')  # <S>
            @typing.overload
            def transform(self, s: scala.Function1[_Promise__KeptPromise__Successful__T, _transform_0__S], f: scala.Function1[java.lang.Throwable, java.lang.Throwable], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_transform_0__S]: ...
            @typing.overload
            def transform(self, f: scala.Function1[scala.util.Try[_Promise__KeptPromise__Successful__T], scala.util.Try[_transform_1__S]], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_transform_1__S]: ...
            _transformWith__S = typing.TypeVar('_transformWith__S')  # <S>
            def transformWith(self, f: scala.Function1[scala.util.Try[_Promise__KeptPromise__Successful__T], scala.concurrent.Future[_transformWith__S]], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_transformWith__S]: ...
            def tryComplete(self, value: scala.util.Try[_Promise__KeptPromise__Successful__T]) -> bool: ...
            def tryCompleteWith(self, other: scala.concurrent.Future[_Promise__KeptPromise__Successful__T]) -> scala.concurrent.Promise[_Promise__KeptPromise__Successful__T]: ...
            def tryFailure(self, cause: java.lang.Throwable) -> bool: ...
            def trySuccess(self, value: _Promise__KeptPromise__Successful__T) -> bool: ...
            def value(self) -> scala.Option[scala.util.Try[_Promise__KeptPromise__Successful__T]]: ...
            def withFilter(self, p: scala.Function1[_Promise__KeptPromise__Successful__T, typing.Any], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_Promise__KeptPromise__Successful__T]: ...
            _zip__U = typing.TypeVar('_zip__U')  # <U>
            def zip(self, that: scala.concurrent.Future[_zip__U]) -> scala.concurrent.Future[scala.Tuple2[_Promise__KeptPromise__Successful__T, _zip__U]]: ...
            _zipWith__U = typing.TypeVar('_zipWith__U')  # <U>
            _zipWith__R = typing.TypeVar('_zipWith__R')  # <R>
            def zipWith(self, that: scala.concurrent.Future[_zipWith__U], f: scala.Function2[_Promise__KeptPromise__Successful__T, _zipWith__U, _zipWith__R], executor: scala.concurrent.ExecutionContext) -> scala.concurrent.Future[_zipWith__R]: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("scala.concurrent.impl")``.

    CallbackRunnable: typing.Type[CallbackRunnable]
    ExecutionContextImpl: typing.Type[ExecutionContextImpl]
    Promise: typing.Type[Promise]



import scala.annotation
import typing



class beanGetter(scala.annotation.Annotation, scala.annotation.StaticAnnotation):
    def __init__(self): ...

class beanSetter(scala.annotation.Annotation, scala.annotation.StaticAnnotation):
    def __init__(self): ...

class companionClass(scala.annotation.Annotation, scala.annotation.StaticAnnotation):
    def __init__(self): ...

class companionMethod(scala.annotation.Annotation, scala.annotation.StaticAnnotation):
    def __init__(self): ...

class companionObject(scala.annotation.Annotation, scala.annotation.StaticAnnotation):
    def __init__(self): ...

class field(scala.annotation.Annotation, scala.annotation.StaticAnnotation):
    def __init__(self): ...

class getter(scala.annotation.Annotation, scala.annotation.StaticAnnotation):
    def __init__(self): ...

class languageFeature(scala.annotation.Annotation, scala.annotation.StaticAnnotation):
    def __init__(self, feature: str, enableRequired: bool): ...

class package: ...

class param(scala.annotation.Annotation, scala.annotation.StaticAnnotation):
    def __init__(self): ...

class setter(scala.annotation.Annotation, scala.annotation.StaticAnnotation):
    def __init__(self): ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("scala.annotation.meta")``.

    beanGetter: typing.Type[beanGetter]
    beanSetter: typing.Type[beanSetter]
    companionClass: typing.Type[companionClass]
    companionMethod: typing.Type[companionMethod]
    companionObject: typing.Type[companionObject]
    field: typing.Type[field]
    getter: typing.Type[getter]
    languageFeature: typing.Type[languageFeature]
    package: typing.Type[package]
    param: typing.Type[param]
    setter: typing.Type[setter]



import sigmastate.Values
import sigmastate.basics
import sigmastate.interpreter
import sigmastate.lang
import sigmastate.serialization
import sigmastate.utils
import typing


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("sigmastate")``.

    Values: sigmastate.Values.__module_protocol__
    basics: sigmastate.basics.__module_protocol__
    interpreter: sigmastate.interpreter.__module_protocol__
    lang: sigmastate.lang.__module_protocol__
    serialization: sigmastate.serialization.__module_protocol__
    utils: sigmastate.utils.__module_protocol__



import java.lang
import java.nio
import scala
import scala.runtime
import scala.util
import scorex.util
import typing



class Reader:
    def __init__(self): ...
    def consumed(self) -> int: ...
    def getBits(self, size: int) -> typing.List[bool]: ...
    def getByte(self) -> int: ...
    def getBytes(self, size: int) -> typing.List[int]: ...
    def getChunk(self, size: int) -> typing.Any: ...
    def getInt(self) -> int: ...
    def getLong(self) -> int: ...
    _getOption__T = typing.TypeVar('_getOption__T')  # <T>
    def getOption(self, getValue: scala.Function0[_getOption__T]) -> scala.Option[_getOption__T]: ...
    def getShort(self) -> int: ...
    def getShortString(self) -> java.lang.String: ...
    def getUByte(self) -> int: ...
    def getUInt(self) -> int: ...
    def getULong(self) -> int: ...
    def getUShort(self) -> int: ...
    def mark(self) -> 'Reader': ...
    def newReader(self, chunk: typing.Any) -> 'Reader': ...
    def peekByte(self) -> int: ...
    def position(self) -> int: ...
    def position_$eq(self, p: int) -> None: ...
    def remaining(self) -> int: ...

_Serializer__TFamily = typing.TypeVar('_Serializer__TFamily')  # <TFamily>
_Serializer__T = typing.TypeVar('_Serializer__T')  # <T>
_Serializer__R = typing.TypeVar('_Serializer__R', bound=Reader)  # <R>
_Serializer__W = typing.TypeVar('_Serializer__W', bound='Writer')  # <W>
class Serializer(typing.Generic[_Serializer__TFamily, _Serializer__T, _Serializer__R, _Serializer__W]):
    def __init__(self): ...
    def parse(self, r: _Serializer__R) -> _Serializer__TFamily: ...
    def parseTry(self, r: _Serializer__R) -> scala.util.Try[_Serializer__TFamily]: ...
    def serialize(self, obj: _Serializer__T, w: _Serializer__W) -> None: ...

class VLQReader:
    @staticmethod
    def $init$($this: 'VLQReader') -> None: ...
    def getBits(self, size: int) -> typing.List[bool]: ...
    def getInt(self) -> int: ...
    def getLong(self) -> int: ...
    _getOption__T = typing.TypeVar('_getOption__T')  # <T>
    def getOption(self, getValue: scala.Function0[_getOption__T]) -> scala.Option[_getOption__T]: ...
    def getShort(self) -> int: ...
    def getShortString(self) -> java.lang.String: ...
    def getUByte(self) -> int: ...
    def getUInt(self) -> int: ...
    def getULong(self) -> int: ...
    def getUShort(self) -> int: ...

class VLQWriter:
    @staticmethod
    def $init$($this: 'VLQWriter') -> None: ...
    def putBits(self, xs: typing.List[bool]) -> 'VLQWriter': ...
    def putInt(self, x: int) -> 'VLQWriter': ...
    def putLong(self, x: int) -> 'VLQWriter': ...
    _putOption__T = typing.TypeVar('_putOption__T')  # <T>
    def putOption(self, x: scala.Option[_putOption__T], putValue: scala.Function2['VLQWriter', _putOption__T, scala.runtime.BoxedUnit]) -> 'VLQWriter': ...
    def putShort(self, x: int) -> 'VLQWriter': ...
    def putShortString(self, s: typing.Union[java.lang.String, str]) -> 'VLQWriter': ...
    def putUInt(self, x: int) -> 'VLQWriter': ...
    def putULong(self, x: int) -> 'VLQWriter': ...
    def putUShort(self, x: int) -> 'VLQWriter': ...
    def toBytes(self) -> typing.List[int]: ...

class Writer:
    def __init__(self): ...
    def append(self, writer: 'Writer') -> 'Writer': ...
    def length(self) -> int: ...
    def newWriter(self) -> 'Writer': ...
    def put(self, x: int) -> 'Writer': ...
    def putBits(self, xs: typing.List[bool]) -> 'Writer': ...
    def putBoolean(self, x: bool) -> 'Writer': ...
    @typing.overload
    def putBytes(self, xs: typing.List[int]) -> 'Writer': ...
    @typing.overload
    def putBytes(self, xs: typing.List[int], offset: int, length: int) -> 'Writer': ...
    def putChunk(self, chunk: typing.Any) -> 'Writer': ...
    def putInt(self, x: int) -> 'Writer': ...
    def putLong(self, x: int) -> 'Writer': ...
    _putOption__T = typing.TypeVar('_putOption__T')  # <T>
    def putOption(self, x: scala.Option[_putOption__T], putValue: scala.Function2['Writer', _putOption__T, scala.runtime.BoxedUnit]) -> 'Writer': ...
    def putShort(self, x: int) -> 'Writer': ...
    def putShortString(self, s: typing.Union[java.lang.String, str]) -> 'Writer': ...
    def putUByte(self, x: int) -> 'Writer': ...
    def putUInt(self, x: int) -> 'Writer': ...
    def putULong(self, x: int) -> 'Writer': ...
    def putUShort(self, x: int) -> 'Writer': ...
    def result(self) -> typing.Any: ...

class VLQByteBufferReader(Reader, VLQReader):
    scorex$util$serialization$VLQByteBufferReader$$buf: java.nio.ByteBuffer = ...
    def __init__(self, buf: java.nio.ByteBuffer): ...
    def consumed(self) -> int: ...
    def getBits(self, size: int) -> typing.List[bool]: ...
    def getByte(self) -> int: ...
    def getBytes(self, size: int) -> typing.List[int]: ...
    def getChunk(self, size: int) -> java.nio.ByteBuffer: ...
    def getInt(self) -> int: ...
    def getLong(self) -> int: ...
    _getOption__T = typing.TypeVar('_getOption__T')  # <T>
    def getOption(self, getValue: scala.Function0[_getOption__T]) -> scala.Option[_getOption__T]: ...
    def getShort(self) -> int: ...
    def getShortString(self) -> java.lang.String: ...
    def getUByte(self) -> int: ...
    def getUInt(self) -> int: ...
    def getULong(self) -> int: ...
    def getUShort(self) -> int: ...
    def mark(self) -> 'VLQByteBufferReader': ...
    def newReader(self, chunk: java.nio.ByteBuffer) -> Reader: ...
    def peekByte(self) -> int: ...
    def position(self) -> int: ...
    def position_$eq(self, p: int) -> None: ...
    def remaining(self) -> int: ...
    def scorex$util$serialization$VLQByteBufferReader$$_mark(self) -> int: ...
    def scorex$util$serialization$VLQByteBufferReader$$_mark_$eq(self, x$1: int) -> None: ...

class VLQByteBufferWriter(Writer, VLQWriter):
    scorex$util$serialization$VLQByteBufferWriter$$b: scorex.util.ByteArrayBuilder = ...
    def __init__(self, b: scorex.util.ByteArrayBuilder): ...
    def length(self) -> int: ...
    def newWriter(self) -> Writer: ...
    def put(self, x: int) -> 'VLQByteBufferWriter': ...
    def putBits(self, xs: typing.List[bool]) -> VLQWriter: ...
    def putBoolean(self, x: bool) -> 'VLQByteBufferWriter': ...
    @typing.overload
    def putBytes(self, xs: typing.List[int]) -> 'VLQByteBufferWriter': ...
    @typing.overload
    def putBytes(self, xs: typing.List[int], offset: int, length: int) -> 'VLQByteBufferWriter': ...
    def putChunk(self, chunk: scorex.util.ByteArrayBuilder) -> 'VLQByteBufferWriter': ...
    def putInt(self, x: int) -> VLQWriter: ...
    def putLong(self, x: int) -> VLQWriter: ...
    _putOption__T = typing.TypeVar('_putOption__T')  # <T>
    def putOption(self, x: scala.Option[_putOption__T], putValue: scala.Function2[VLQWriter, _putOption__T, scala.runtime.BoxedUnit]) -> VLQWriter: ...
    def putShort(self, x: int) -> VLQWriter: ...
    def putShortString(self, s: typing.Union[java.lang.String, str]) -> VLQWriter: ...
    def putUInt(self, x: int) -> VLQWriter: ...
    def putULong(self, x: int) -> VLQWriter: ...
    def putUShort(self, x: int) -> VLQWriter: ...
    def result(self) -> scorex.util.ByteArrayBuilder: ...
    def toBytes(self) -> typing.List[int]: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("scorex.util.serialization")``.

    Reader: typing.Type[Reader]
    Serializer: typing.Type[Serializer]
    VLQByteBufferReader: typing.Type[VLQByteBufferReader]
    VLQByteBufferWriter: typing.Type[VLQByteBufferWriter]
    VLQReader: typing.Type[VLQReader]
    VLQWriter: typing.Type[VLQWriter]
    Writer: typing.Type[Writer]
